==> oht-0.2.1.tgz: package/src/base/Endpoint.ts <==
import {OHTClient} from '../OHTClient';
import * as querystring from 'querystring';
import * as https from 'https';
import * as request from 'request';


const DEFAULT_HEADERS = {
    'Content-Type': 'multipart/form-data'
};


export class Endpoint {
    client : OHTClient = undefined;
    baseUrl : string = undefined;

    constructor(client : OHTClient) {
        this.client = client; 
        this.baseUrl = '';
    }

    /**
     * Perform the HTTP request described by the method arguments.
     *
     * @param {string} method   An HTTP verb/method.
     * @param {string} path     The relative path for the resource.
     * @param {object} params   An object with the querystring params.
     */
    request(method, path, params={}, headers={}, data={}) {
        // Create the querystring for the given params and add the 
        // credentials.
        const options = this.client.options;
        const qs = querystring.stringify(Object.assign(
            {}, 
            params, 
            {
                secret_key: options.credentials.secretKey,
                public_key: options.credentials.publicKey
            }
        ));

        // Discard undefined values in the data object.
        for (let property in data) {
            if (data[property] === undefined)  {
                delete data[property];
            }
        }

        // Generate the options object for the http.request method.
        const url = (
            options.protocol + '://' + options.hostname + options.basePath + path
            + '?' + qs
        );
        const requestData = {
            method: method.toUpperCase(),
            uri: url,
            headers: Object.assign({}, DEFAULT_HEADERS, headers),
            formData: data
        };

        console.log(method, path);
        console.log(data);

        // Wrap the http.request method in a promise.
        return new Promise((resolve, reject) => {
            try {
                const req = request(requestData, (error, res, data) => {
                    if (error || res.statusCode >= 400) {
                        return reject(error);
                    }

                    resolve(JSON.parse(data));
                });
            } catch(e) {
                reject(e); 
            }

        });
    }
}

==> oht-0.2.2.tgz: package/src/base/Endpoint.ts <==
import {Client} from '../Client';
import * as querystring from 'querystring';
import * as https from 'https';
import * as request from 'request';


const DEFAULT_HEADERS = {
    'Content-Type': 'multipart/form-data'
};


export class Endpoint {
    client : Client = undefined;
    baseUrl : string = undefined;

    constructor(client : Client) {
        this.client = client;
        this.baseUrl = '';
    }

    /**
     * Perform the HTTP request described by the method arguments.
     *
     * @param {string} method   An HTTP verb/method.
     * @param {string} path     The relative path for the resource.
     * @param {object} params   An object with the querystring params.
     */
    request(method, path, params={}, headers={}, data={}) {
        // Create the querystring for the given params and add the
        // credentials.
        const options = this.client.options;
        const qs = querystring.stringify(Object.assign(
            {},
            params,
            {
                secret_key: options.credentials.secretKey,
                public_key: options.credentials.publicKey
            }
        ));

        // Discard undefined values in the data object.
        for (let property in data) {
            if (data[property] === undefined)  {
                delete data[property];
            }
        }

        // Generate the options object for the http.request method.
        const url = (
            options.protocol + '://' + options.hostname + options.basePath + path
            + '?' + qs
        );
        const requestData = {
            method: method.toUpperCase(),
            uri: url,
            headers: Object.assign({}, DEFAULT_HEADERS, headers),
            formData: data
        };

        // Wrap the http.request method in a promise.
        return new Promise((resolve, reject) => {
            try {
                const req = request(requestData, (error, res, data) => {
                    if (error || res.statusCode >= 400) {
                        return reject(error);
                    }

                    resolve(JSON.parse(data));
                });
            } catch(e) {
                reject(e);
            }

        });
    }
}
